@@ -18,7 +18,7 @@ if __name__ == "__main__":
         pass
     print
     p=py2deb.Py2deb("scm")   #This is the package name and MUST be in lowercase! (using  "mClock" fails miserably, for example)
-    p.description="A GUI for making Contact Shortcuts for your Desktop"
+    p.description="A GUI for making Shortcuts for your Desktop"
     p.author="Tiboric"
     p.mail="Tiboric@aol.com"
     p.depends = "python2.5, python-osso, python-dbus, python2.5-gtk2, rootsh"
@@ -32,14 +32,14 @@ if __name__ == "__main__":
     p.repository="extras-devel"
     p.xsbc_bugtracker="http://bugs.maemo.org"
     p.postinstall="""#!/bin/sh
-  chmod +x /opt/shortcutmkr/main.py""" #Set here your post install script
+      chmod +x /opt/shortcutmkr/main.py"""
     #  p.postremove="""chmod +x /opt/shortcutmkr/main.py""" #Set here your post remove script
     #  p.preinstall="""chmod +x /opt/shortcutmkr/main.py""" #Set here your pre install script
     #  p.preremove="""chmod +x /opt/shortcutmkr/main.py""" #Set here your pre remove script
-    version = "0.6.0"           #Version of your software, for example "1.2.0" or "0.8.2"
-    build = "3"                 #Build number, for example "1" for the first build of this version of your software. Increment for later re-builds of the same version of your software.
+    version = "0.7.1"           #Version of your software, for example "1.2.0" or "0.8.2"
+    build = "1"                 #Build number, for example "1" for the first build of this version of your software. Increment for later re-builds of the same version of your software.
                                 #Text with changelog information to be displayed in the package "Details" tab of the Maemo Application Manager
-    changeloginformation = "Fixed bug with startup." 
+    changeloginformation = "added simple icon chooser" 
     dir_name = "src"            #Name of the subfolder containing your package source files (for example, usr\share\icons\hicolor\scalable\myappicon.svg, usr\lib\myapp\somelib.py). We suggest to leave it named src in all projects and will refer to that in the wiki article on maemo.org
     #Thanks to DareTheHair from talk.maemo.org for this snippet that recursively builds the file list.
     for root, dirs, files in os.walk(dir_name):
